@@ -1,5 +1,5 @@
 package App::rshasum;
-$App::rshasum::VERSION = '0.6.4';
+$App::rshasum::VERSION = '0.8.0';
 use 5.016;
 use strict;
 use warnings;
@@ -39,7 +39,7 @@ FILES:
             my $fh;
             if ( not( open $fh, '<', $r->path ) )
             {
-                warn "Could not open @{[$r->path]}; skipping";
+                warn "Could not open @{[$r->path]} ; skipping";
                 next FILES;
             }
             binmode $fh;
@@ -100,7 +100,7 @@ App::rshasum - recursive shasum.
 
 =head1 VERSION
 
-version 0.6.4
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -141,6 +141,17 @@ current working directory).
 
 Runs the app.
 
+=head1 SEE ALSO
+
+L<https://github.com/rhash/RHash> - "recursive hash". Seems to emit the
+tree in an unpredictable, not-always-sorted, order.
+
+L<https://www.shlomifish.org/open-source/projects/File-Dir-Dumper/> - also
+on CPAN. Dumps metadata and supports caching the digests.
+
+L<https://github.com/gokyle/rshasum> - written in golang, but slurps
+entire files into memory (see L<https://github.com/gokyle/rshasum/issues/1> ).
+
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
